@@ -36,3 +36,19 @@ fact <- function(n) {
     dim(f) <- d
     return(f)
 }
+
+
+factorial2 <- function(n) {
+    stopifnot(is.numeric(n) || length(n) > 1)
+    n = floor(n)
+    if (n > 170) return(Inf)
+    if (n < 0)   return(NaN)
+    if (n == 0)  return(1)
+
+    if (n %% 2 == 0) {
+        return( prod(seq(from = 2, to = n, by = 2)) )
+    } else {
+        return( prod(seq(from = 1, to = n, by = 2)) )
+    }
+}
+
